@@ -1,42 +1,49 @@
-# -*- coding: utf-8 -*-
 """
 Manage transport commands via ssh
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
 import logging
 import os
-
-# Import python libs
 import re
 import shlex
 import subprocess
 import sys
 import time
 
-# Import salt libs
 import salt.defaults.exitcodes
 import salt.utils.json
 import salt.utils.nb_popen
+import salt.utils.path
 import salt.utils.vt
-from salt.ext import six
 
 log = logging.getLogger(__name__)
 
-SSH_PASSWORD_PROMPT_RE = re.compile(r"(?:.*)[Pp]assword(?: for .*)?:", re.M)
+SSH_PASSWORD_PROMPT_RE = re.compile(r"(?:.*)[Pp]assword(?: for .*)?:\s*$", re.M)
 KEY_VALID_RE = re.compile(r".*\(yes\/no\).*")
 SSH_PRIVATE_KEY_PASSWORD_PROMPT_RE = re.compile(r"Enter passphrase for key", re.M)
 
+# sudo prompt is used to recognize sudo prompting for a password and should
+# therefore be fairly recognizable and unique
+SUDO_PROMPT = "[salt:sudo:d11bd4221135c33324a6bdc09674146fbfdf519989847491e34a689369bbce23]passwd:"
+SUDO_PROMPT_RE = re.compile(
+    r"\[salt:sudo:d11bd4221135c33324a6bdc09674146fbfdf519989847491e34a689369bbce23\]passwd:",
+    re.M,
+)
+
 # Keep these in sync with ./__init__.py
 RSTR = "_edbc7885e4f9aac9b83b35999b68d015148caf467b78fa39c05f669c0ff89878"
 RSTR_RE = re.compile(r"(?:^|\r?\n)" + RSTR + r"(?:\r?\n|$)")
 
+SSH_KEYGEN_PATH = salt.utils.path.which("ssh-keygen") or "ssh-keygen"
+SSH_PATH = salt.utils.path.which("ssh") or "ssh"
+SCP_PATH = salt.utils.path.which("scp") or "scp"
+
 
 def gen_key(path):
     """
     Generate a key for use with salt-ssh
     """
-    cmd = ["ssh-keygen", "-P", '""', "-f", path, "-t", "rsa", "-q"]
+    cmd = [SSH_KEYGEN_PATH, "-P", "", "-f", path, "-t", "rsa", "-q"]
     dirname = os.path.dirname(path)
     if dirname and not os.path.isdir(dirname):
         os.makedirs(os.path.dirname(path))
@@ -60,7 +67,7 @@ def gen_shell(opts, **kwargs):
     return shell
 
 
-class Shell(object):
+class Shell:
     """
     Create a shell connection object to encapsulate ssh executions
     """
@@ -85,11 +92,11 @@ class Shell(object):
         ssh_options=None,
     ):
         self.opts = opts
-        # ssh <ipv6>, but scp [<ipv6]:/path
+        # ssh <ipv6>, but scp [<ipv6>]:/path
         self.host = host.strip("[]")
         self.user = user
         self.port = port
-        self.passwd = six.text_type(passwd) if passwd else passwd
+        self.passwd = str(passwd) if passwd else passwd
         self.priv = priv
         self.priv_passwd = priv_passwd
         self.timeout = timeout
@@ -127,26 +134,26 @@ class Shell(object):
             options.append("PasswordAuthentication=no")
         if self.opts.get("_ssh_version", (0,)) > (4, 9):
             options.append("GSSAPIAuthentication=no")
-        options.append("ConnectTimeout={0}".format(self.timeout))
+        options.append(f"ConnectTimeout={self.timeout}")
         if self.opts.get("ignore_host_keys"):
             options.append("StrictHostKeyChecking=no")
         if self.opts.get("no_host_keys"):
             options.extend(["StrictHostKeyChecking=no", "UserKnownHostsFile=/dev/null"])
         known_hosts = self.opts.get("known_hosts_file")
         if known_hosts and os.path.isfile(known_hosts):
-            options.append("UserKnownHostsFile={0}".format(known_hosts))
+            options.append(f"UserKnownHostsFile={known_hosts}")
         if self.port:
-            options.append("Port={0}".format(self.port))
+            options.append(f"Port={self.port}")
         if self.priv and self.priv != "agent-forwarding":
-            options.append("IdentityFile={0}".format(self.priv))
+            options.append(f"IdentityFile={self.priv}")
         if self.user:
-            options.append("User={0}".format(self.user))
+            options.append(f"User={self.user}")
         if self.identities_only:
             options.append("IdentitiesOnly=yes")
 
         ret = []
         for option in options:
-            ret.append("-o {0} ".format(option))
+            ret.append(f"-o {option} ")
         return "".join(ret)
 
     def _passwd_opts(self):
@@ -162,7 +169,7 @@ class Shell(object):
         ]
         if self.opts["_ssh_version"] > (4, 9):
             options.append("GSSAPIAuthentication=no")
-        options.append("ConnectTimeout={0}".format(self.timeout))
+        options.append(f"ConnectTimeout={self.timeout}")
         if self.opts.get("ignore_host_keys"):
             options.append("StrictHostKeyChecking=no")
         if self.opts.get("no_host_keys"):
@@ -181,19 +188,19 @@ class Shell(object):
                 ]
             )
         if self.port:
-            options.append("Port={0}".format(self.port))
+            options.append(f"Port={self.port}")
         if self.user:
-            options.append("User={0}".format(self.user))
+            options.append(f"User={self.user}")
         if self.identities_only:
             options.append("IdentitiesOnly=yes")
 
         ret = []
         for option in options:
-            ret.append("-o {0} ".format(option))
+            ret.append(f"-o {option} ")
         return "".join(ret)
 
     def _ssh_opts(self):
-        return " ".join(["-o {0}".format(opt) for opt in self.ssh_options])
+        return " ".join([f"-o {opt}" for opt in self.ssh_options])
 
     def _copy_id_str_old(self):
         """
@@ -202,9 +209,9 @@ class Shell(object):
         if self.passwd:
             # Using single quotes prevents shell expansion and
             # passwords containing '$'
-            return "{0} {1} '{2} -p {3} {4} {5}@{6}'".format(
+            return "{} {} '{} -p {} {} {}@{}'".format(
                 "ssh-copy-id",
-                "-i {0}.pub".format(self.priv),
+                f"-i {self.priv}.pub",
                 self._passwd_opts(),
                 self.port,
                 self._ssh_opts(),
@@ -221,9 +228,9 @@ class Shell(object):
         if self.passwd:
             # Using single quotes prevents shell expansion and
             # passwords containing '$'
-            return "{0} {1} {2} -p {3} {4} {5}@{6}".format(
+            return "{} {} {} -p {} {} {}@{}".format(
                 "ssh-copy-id",
-                "-i {0}.pub".format(self.priv),
+                f"-i {self.priv}.pub",
                 self._passwd_opts(),
                 self.port,
                 self._ssh_opts(),
@@ -241,7 +248,7 @@ class Shell(object):
             stdout, stderr, retcode = self._run_cmd(self._copy_id_str_new())
         return stdout, stderr, retcode
 
-    def _cmd_str(self, cmd, ssh="ssh"):
+    def _cmd_str(self, cmd, ssh=SSH_PATH):
         """
         Return the cmd string to execute
         """
@@ -250,19 +257,16 @@ class Shell(object):
         # need to deliver the SHIM to the remote host and execute it there
 
         command = [ssh]
-        if ssh != "scp":
+        if ssh != SCP_PATH:
             command.append(self.host)
-        if self.tty and ssh == "ssh":
+        if self.tty and ssh == SSH_PATH:
             command.append("-t -t")
         if self.passwd or self.priv:
             command.append(self.priv and self._key_opts() or self._passwd_opts())
-        if ssh != "scp" and self.remote_port_forwards:
+        if ssh != SCP_PATH and self.remote_port_forwards:
             command.append(
                 " ".join(
-                    [
-                        "-R {0}".format(item)
-                        for item in self.remote_port_forwards.split(",")
-                    ]
+                    [f"-R {item}" for item in self.remote_port_forwards.split(",")]
                 )
             )
         if self.ssh_options:
@@ -278,7 +282,9 @@ class Shell(object):
         """
         try:
             proc = salt.utils.nb_popen.NonBlockingPopen(
-                self._split_cmd(cmd), stderr=subprocess.PIPE, stdout=subprocess.PIPE,
+                self._split_cmd(cmd),
+                stderr=subprocess.PIPE,
+                stdout=subprocess.PIPE,
             )
             while True:
                 time.sleep(0.1)
@@ -302,7 +308,7 @@ class Shell(object):
         rcode = None
         cmd = self._cmd_str(cmd)
 
-        logmsg = "Executing non-blocking command: {0}".format(cmd)
+        logmsg = f"Executing non-blocking command: {cmd}"
         if self.passwd:
             logmsg = logmsg.replace(self.passwd, ("*" * 6))
         log.debug(logmsg)
@@ -321,7 +327,7 @@ class Shell(object):
         """
         cmd = self._cmd_str(cmd)
 
-        logmsg = "Executing command: {0}".format(cmd)
+        logmsg = f"Executing command: {cmd}"
         if self.passwd:
             logmsg = logmsg.replace(self.passwd, ("*" * 6))
         if 'decode("base64")' in logmsg or "base64.b64decode(" in logmsg:
@@ -338,17 +344,25 @@ class Shell(object):
         scp a file or files to a remote system
         """
         if makedirs:
-            self.exec_cmd("mkdir -p {0}".format(os.path.dirname(remote)))
+            pardir = os.path.dirname(remote)
+            if not pardir:
+                log.warning(
+                    "Makedirs called on relative filename: '%s'. Skipping.", remote
+                )
+            else:
+                ret = self.exec_cmd("mkdir -p " + shlex.quote(pardir))
+                if ret[2]:
+                    return ret
 
-        # scp needs [<ipv6}
+        # scp needs [<ipv6>]
         host = self.host
         if ":" in host:
-            host = "[{0}]".format(host)
+            host = f"[{host}]"
 
-        cmd = "{0} {1}:{2}".format(local, host, remote)
-        cmd = self._cmd_str(cmd, ssh="scp")
+        cmd = f"{local} {host}:{remote}"
+        cmd = self._cmd_str(cmd, ssh=SCP_PATH)
 
-        logmsg = "Executing command: {0}".format(cmd)
+        logmsg = f"Executing command: {cmd}"
         if self.passwd:
             logmsg = logmsg.replace(self.passwd, ("*" * 6))
         log.debug(logmsg)
@@ -367,9 +381,16 @@ class Shell(object):
             cmd_lst = shlex.split(cmd)
         else:
             cmd_lst = shlex.split(ssh_part)
-            cmd_lst.append("/bin/sh {}".format(cmd_part))
+            cmd_lst.append(f"/bin/sh {cmd_part}")
         return cmd_lst
 
+    def _sanitize_str(self, text, sanitize_text):
+        """Remove all occurrences of sanitize_text from text"""
+        if not sanitize_text:
+            return text
+        replace_str = "*" * 6
+        return re.sub(r"\b" + re.escape(sanitize_text) + r"\b", replace_str, text)
+
     def _run_cmd(self, cmd, key_accept=False, passwd_retries=3):
         """
         Execute a shell command via VT. This is blocking and assumes that ssh
@@ -378,12 +399,16 @@ class Shell(object):
         if not cmd:
             return "", "No command or passphrase", 245
 
+        log_sanitize = None
+        if self.passwd:
+            log_sanitize = self.passwd
         term = salt.utils.vt.Terminal(
             self._split_cmd(cmd),
             log_stdout=True,
             log_stdout_level="trace",
             log_stderr=True,
             log_stderr_level="trace",
+            log_sanitize=log_sanitize,
             stream_stdout=False,
             stream_stderr=False,
         )
@@ -434,9 +459,15 @@ class Shell(object):
                         ret_stdout = (
                             "The host key needs to be accepted, to "
                             "auto accept run salt-ssh with the -i "
-                            "flag:\n{0}"
-                        ).format(stdout)
+                            f"flag:\n{self._sanitize_str(stdout, self.passwd)}"
+                        )
                         return ret_stdout, "", 254
+                elif buff and SUDO_PROMPT_RE.search(buff):
+                    if not self.passwd:
+                        return "", "Sudo password is required but not provided", 254
+                    else:
+                        term.sendline(self.passwd)
+                        continue
                 elif buff and buff.endswith("_||ext_mods||_"):
                     mods_raw = (
                         salt.utils.json.dumps(self.mods, separators=(",", ":"))
@@ -446,6 +477,21 @@ class Shell(object):
                 if stdout:
                     old_stdout = stdout
                 time.sleep(0.01)
-            return ret_stdout, ret_stderr, term.exitstatus
         finally:
             term.close(terminate=True, kill=True)
+        # Ensure term.close is called before querying the exitstatus, otherwise
+        # it might still be None.
+        ret_status = term.exitstatus
+        if ret_status is None:
+            if term.signalstatus is not None:
+                # The process died because of an unhandled signal, report
+                # a non-zero exitcode bash-style.
+                ret_status = 128 + term.signalstatus
+            else:
+                log.warning(
+                    "VT reported both exitstatus and signalstatus as None. "
+                    "This is likely a bug."
+                )
+        ret_stdout = self._sanitize_str(ret_stdout, self.passwd)
+        ret_stderr = self._sanitize_str(ret_stderr, self.passwd)
+        return ret_stdout, ret_stderr, ret_status
