@@ -78,6 +78,18 @@ class CMDModuleTest(ModuleCase):
             ),
             "four\nfive",
         )
+        self.assertEqual(
+            self.run_function(
+                "cmd.run", ["cat"], stdin="one\\ntwo", stdin_raw_newlines=False
+            ),
+            "one\ntwo",
+        )
+        self.assertEqual(
+            self.run_function(
+                "cmd.run", ["cat"], stdin="one\\ntwo", stdin_raw_newlines=True
+            ),
+            "one\\ntwo",
+        )
         self.assertEqual(
             self.run_function(
                 "cmd.run", ['echo "a=b" | sed -e s/=/:/g'], python_shell=True
@@ -213,6 +225,7 @@ class CMDModuleTest(ModuleCase):
         )
 
     @pytest.mark.slow_test
+    @pytest.mark.skip_on_windows
     def test_script(self):
         """
         cmd.script
@@ -223,6 +236,7 @@ class CMDModuleTest(ModuleCase):
         self.assertEqual(ret["stdout"], args)
 
     @pytest.mark.slow_test
+    @pytest.mark.skip_on_windows
     def test_script_query_string(self):
         """
         cmd.script
@@ -233,6 +247,7 @@ class CMDModuleTest(ModuleCase):
         self.assertEqual(ret["stdout"], args)
 
     @pytest.mark.slow_test
+    @pytest.mark.skip_on_windows
     def test_script_retcode(self):
         """
         cmd.script_retcode
@@ -242,6 +257,7 @@ class CMDModuleTest(ModuleCase):
         self.assertEqual(ret, 0)
 
     @pytest.mark.slow_test
+    @pytest.mark.skip_on_windows
     def test_script_cwd(self):
         """
         cmd.script with cwd
@@ -255,6 +271,7 @@ class CMDModuleTest(ModuleCase):
         self.assertEqual(ret["stdout"], args)
 
     @pytest.mark.slow_test
+    @pytest.mark.skip_on_windows
     def test_script_cwd_with_space(self):
         """
         cmd.script with cwd
@@ -376,10 +393,11 @@ class CMDModuleTest(ModuleCase):
         """
         cmd.run with quoted command
         """
-        cmd = """echo 'SELECT * FROM foo WHERE bar="baz"' """
-        expected_result = 'SELECT * FROM foo WHERE bar="baz"'
         if salt.utils.platform.is_windows():
-            expected_result = "'SELECT * FROM foo WHERE bar=\"baz\"'"
+            cmd = """echo SELECT * FROM foo WHERE bar="baz" """
+        else:
+            cmd = """echo 'SELECT * FROM foo WHERE bar="baz"' """
+        expected_result = 'SELECT * FROM foo WHERE bar="baz"'
         result = self.run_function("cmd.run_stdout", [cmd]).strip()
         self.assertEqual(result, expected_result)
 
@@ -503,7 +521,7 @@ class CMDModuleTest(ModuleCase):
         """
         with self._ensure_user_exists(self.runas_usr):
             out = self.run_function(
-                "cmd.run", ["env"], runas=self.runas_usr
+                "cmd.run", ["env"], runas=self.runas_usr, cwd="/tmp"
             ).splitlines()
         self.assertIn(f"USER={self.runas_usr}", out)
 
