@@ -5,6 +5,7 @@ Integration tests for Ruby Gem module
 import pytest
 from tornado.httpclient import HTTPClient
 
+import salt.utils.platform
 from tests.support.case import ModuleCase
 
 
@@ -31,6 +32,7 @@ class GemModuleTest(ModuleCase):
         if check_status() is False:
             self.skipTest("External resource 'https://rubygems.org' is not available")
 
+        self.GEM_BIN = "gem.cmd" if salt.utils.platform.is_windows() else "gem"
         self.GEM = "tidy"
         self.GEM_VER = "1.1.2"
         self.OLD_GEM = "brass"
@@ -54,6 +56,11 @@ class GemModuleTest(ModuleCase):
 
         self.addCleanup(uninstall_gem)
 
+    def run_function(self, function, *args, **kwargs):
+        """Override run_function to use the gem binary"""
+        kwargs["gem_bin"] = self.GEM_BIN
+        return super().run_function(function, *args, **kwargs)
+
     @pytest.mark.slow_test
     def test_install_uninstall(self):
         """
