@@ -10,7 +10,6 @@ import time
 from pathlib import Path
 
 import pytest
-from pytestshellutils.utils import ports
 from saltfactories.utils import random_string
 
 import salt.channel.client
@@ -69,38 +68,27 @@ def transport(request):
 
 
 @pytest.fixture
-def master_config(root_dir, transport):
-    master_conf = salt.config.master_config("")
-    master_conf.update(
+def master_config(master_opts, transport):
+    master_opts.update(
         transport=transport,
         id="master",
-        root_dir=str(root_dir),
-        sock_dir=str(root_dir),
         interface="127.0.0.1",
-        publish_port=ports.get_unused_localhost_port(),
-        ret_port=ports.get_unused_localhost_port(),
-        pki_dir=str(root_dir / "pki"),
         fips_mode=FIPS_TESTRUN,
         publish_signing_algorithm=(
             "PKCS1v15-SHA224" if FIPS_TESTRUN else "PKCS1v15-SHA1"
         ),
     )
-    os.makedirs(master_conf["pki_dir"])
-    salt.crypt.gen_keys(master_conf["pki_dir"], "master", 4096)
-    minions_keys = os.path.join(master_conf["pki_dir"], "minions")
-    os.makedirs(minions_keys)
-    yield master_conf
+    salt.crypt.gen_keys(master_opts["pki_dir"], "master", 4096)
+    yield master_opts
 
 
 @pytest.fixture
-def minion_config(master_config, channel_minion_id):
-    minion_conf = salt.config.minion_config(
-        "", minion_id=channel_minion_id, cache_minion_id=False
-    )
-    minion_conf.update(
+def minion_config(minion_opts, master_config, channel_minion_id):
+    minion_opts.update(
         transport=master_config["transport"],
         root_dir=master_config["root_dir"],
         id=channel_minion_id,
+        cachedir=master_config["cachedir"],
         sock_dir=master_config["sock_dir"],
         ret_port=master_config["ret_port"],
         interface="127.0.0.1",
@@ -112,12 +100,13 @@ def minion_config(master_config, channel_minion_id):
         encryption_algorithm="OAEP-SHA224" if FIPS_TESTRUN else "OAEP-SHA1",
         signing_algorithm="PKCS1v15-SHA224" if FIPS_TESTRUN else "PKCS1v15-SHA1",
     )
-    os.makedirs(minion_conf["pki_dir"])
-    salt.crypt.gen_keys(minion_conf["pki_dir"], "minion", 4096)
-    minion_pub = os.path.join(minion_conf["pki_dir"], "minion.pub")
+    pathlib.Path(minion_opts["pki_dir"]).mkdir(exist_ok=True)
+    pathlib.Path(master_config["pki_dir"]).mkdir(exist_ok=True)
+    salt.crypt.gen_keys(minion_opts["pki_dir"], "minion", 4096)
+    minion_pub = os.path.join(minion_opts["pki_dir"], "minion.pub")
     pub_on_master = os.path.join(master_config["pki_dir"], "minions", channel_minion_id)
     shutil.copyfile(minion_pub, pub_on_master)
-    return minion_conf
+    return minion_opts
 
 
 @pytest.fixture
