@@ -4,17 +4,26 @@ import subprocess
 
 import psutil
 import pytest
+
 import salt.exceptions
 
 pytestmark = [
     pytest.mark.windows_whitelisted,
     pytest.mark.skip_unless_on_windows,
+    pytest.mark.slow_test,
 ]
 
 
 @pytest.fixture(scope="module")
 def dsc(modules):
-    return modules.dsc
+    # We seem to be hitting an issue where there is a consistency check in
+    # progress during some of the tests. When this happens, the test fails
+    # This should disabled background refreshes
+    # https://github.com/saltstack/salt/issues/62714
+    existing_config_mode = modules.dsc.get_lcm_config()["ConfigurationMode"]
+    modules.dsc.set_lcm_config(config_mode="ApplyOnly")
+    yield modules.dsc
+    modules.dsc.set_lcm_config(config_mode=existing_config_mode)
 
 
 @pytest.fixture(scope="function")
@@ -70,7 +79,7 @@ def ps1_file_multiple():
                 Ensure          = "Present"
                 Contents        = "Hello World from DSC!"
             }
-            
+
             # The File resource can ensure the state of files, or copy them from a source to a destination with persistent updates.
             File HelloWorld2 {
                 DestinationPath = "C:\Temp\HelloWorld2.txt"
@@ -158,7 +167,7 @@ def test_compile_config_missing(dsc):
     path = "C:\\Path\\not\\exists.ps1"
     with pytest.raises(salt.exceptions.CommandExecutionError) as exc:
         dsc.compile_config(path=path)
-    assert exc.value.message == "{} not found".format(path)
+    assert exc.value.message == f"{path} not found"
 
 
 @pytest.mark.destructive_test
@@ -195,7 +204,7 @@ def test_apply_config_missing(dsc):
     path = "C:\\Path\\not\\exists"
     with pytest.raises(salt.exceptions.CommandExecutionError) as exc:
         dsc.apply_config(path=path)
-    assert exc.value.message == "{} not found".format(path)
+    assert exc.value.message == f"{path} not found"
 
 
 @pytest.mark.destructive_test
@@ -213,7 +222,6 @@ def test_apply_config(dsc, ps1_file, psd1_file):
     assert result is True
 
 
-@pytest.mark.flaky(max_runs=6)
 def test_get_config_not_configured(dsc):
     dsc.remove_config(reset=False)
     with pytest.raises(salt.exceptions.CommandExecutionError) as exc:
@@ -221,7 +229,6 @@ def test_get_config_not_configured(dsc):
     assert exc.value.message == "Not Configured"
 
 
-@pytest.mark.flaky(max_runs=4)
 def test_get_config_single(dsc, ps1_file, psd1_file):
     dsc.remove_config(reset=False)
     dsc.run_config(
@@ -274,7 +281,6 @@ def _reset_config(dsc):
             continue
 
 
-@pytest.mark.flaky(max_runs=4)
 def test_get_config_status_not_configured(dsc):
     _reset_config(dsc)
     with pytest.raises(salt.exceptions.CommandExecutionError) as exc:
