@@ -264,7 +264,7 @@ async def test_pub_channel(master_opts, io_loop):
     io_loop.add_callback(
         server.publisher,
         publish_payload,
-        ioloop=io_loop,
+        io_loop=io_loop,
     )
 
     await asyncio.sleep(3)
@@ -302,7 +302,7 @@ async def test_pub_channel_filtering(master_opts, io_loop):
     io_loop.add_callback(
         server.publisher,
         publish_payload,
-        ioloop=io_loop,
+        io_loop=io_loop,
     )
 
     await asyncio.sleep(3)
@@ -338,7 +338,7 @@ async def test_pub_channel_filtering_topic(master_opts, io_loop):
     io_loop.add_callback(
         server.publisher,
         publish_payload,
-        ioloop=io_loop,
+        io_loop=io_loop,
     )
 
     await asyncio.sleep(3)
