@@ -83,3 +83,16 @@ def test_named_loader_context_name_not_packed(tmp_path):
             match="LazyLoader does not have a packed value for: __not_packed__",
         ):
             loader["mymod.foobar"]()
+
+
+def test_return_named_context_from_loaded_func(tmp_path):
+    opts = {
+        "optimization_order": [0],
+    }
+    contents = """
+    def foobar():
+        return __test__
+    """
+    with pytest.helpers.temp_file("mymod.py", contents, directory=tmp_path):
+        loader = salt.loader.LazyLoader([tmp_path], opts, pack={"__test__": "meh"})
+        assert loader["mymod.foobar"]() == "meh"
