@@ -140,7 +140,9 @@ def test_push():
     ), patch.multiple(
         "salt.modules.cp",
         _auth=MagicMock(**{"return_value.gen_token.return_value": "token"}),
-        __opts__={"id": "abc", "file_buffer_size": 10},
+        __opts__=salt.loader.dunder.__opts__.with_default(
+            {"id": "abc", "file_buffer_size": 10}
+        ),
     ), patch(
         "salt.utils.files.fopen", mock_open(read_data=b"content")
     ) as m_open, patch(
@@ -157,7 +159,6 @@ def test_push():
             dict(
                 loc=fh_.tell(),  # pylint: disable=resource-leakage
                 cmd="_file_recv",
-                tok="token",
                 path=["saltines", "test.file"],
                 size=10,
                 data=b"",  # data is empty here because load['data'] is overwritten
