@@ -4,12 +4,11 @@
 
 import logging
 import textwrap
-from collections import OrderedDict
 
 import pytest  # pylint: disable=unused-import
 
 import salt.state
-from salt.utils.datastructures import DefaultOrderedDict
+from salt.utils.odict import DefaultOrderedDict, OrderedDict
 
 log = logging.getLogger(__name__)
 
@@ -324,6 +323,7 @@ def test_dont_extend_in_excluded_sls_file(highstate, state_tree_dir):
                             ),
                             ("__sls__", "test2"),
                             ("__env__", "base"),
+                            ("__sls_included_from__", ["test1"]),
                         ]
                     ),
                 ),
