@@ -10,9 +10,9 @@ import signal
 import time
 
 import pytest
+import tornado.ioloop
 from saltfactories.utils import random_string
 
-import salt.ext.tornado.ioloop
 import salt.fileserver.gitfs
 import salt.utils.files
 import salt.utils.gitfs
@@ -44,9 +44,7 @@ def _get_user():
 
 def _clear_instance_map():
     try:
-        del salt.utils.gitfs.GitFS.instance_map[
-            salt.ext.tornado.ioloop.IOLoop.current()
-        ]
+        del salt.utils.gitfs.GitFS.instance_map[tornado.ioloop.IOLoop.current()]
     except KeyError:
         pass
 
