@@ -1,10 +1,11 @@
-import salt.ext.tornado
-import salt.ext.tornado.testing
+import tornado
+import tornado.testing
+
 import salt.netapi.rest_tornado.saltnado as saltnado
 from tests.support.mock import MagicMock, patch
 
 
-class TestJobNotRunning(salt.ext.tornado.testing.AsyncTestCase):
+class TestJobNotRunning(tornado.testing.AsyncTestCase):
     def setUp(self):
         super().setUp()
         self.mock = MagicMock()
@@ -23,11 +24,11 @@ class TestJobNotRunning(salt.ext.tornado.testing.AsyncTestCase):
         self.handler.lowstate = []
         self.handler.content_type = "text/plain"
         self.handler.dumper = lambda x: x
-        f = salt.ext.tornado.gen.Future()
+        f = tornado.gen.Future()
         f.set_result({"jid": f, "minions": []})
         self.handler.saltclients.update({"local": lambda *args, **kwargs: f})
 
-    @salt.ext.tornado.testing.gen_test
+    @tornado.testing.gen_test
     def test_when_disbatch_has_already_finished_then_writing_return_should_not_fail(
         self,
     ):
@@ -37,7 +38,7 @@ class TestJobNotRunning(salt.ext.tornado.testing.AsyncTestCase):
         # Asserting that it doesn't raise anything is... the default behavior
         # for a test.
 
-    @salt.ext.tornado.testing.gen_test
+    @tornado.testing.gen_test
     def test_when_disbatch_has_already_finished_then_finishing_should_not_fail(self):
         self.handler.finish()
         result = yield self.handler.disbatch()
@@ -45,12 +46,12 @@ class TestJobNotRunning(salt.ext.tornado.testing.AsyncTestCase):
         # Asserting that it doesn't raise anything is... the default behavior
         # for a test.
 
-    @salt.ext.tornado.testing.gen_test
+    @tornado.testing.gen_test
     def test_when_event_times_out_and_minion_is_not_running_result_should_be_True(self):
-        fut = salt.ext.tornado.gen.Future()
+        fut = tornado.gen.Future()
         fut.set_exception(saltnado.TimeoutException())
         self.mock.event_listener.get_event.return_value = fut
-        wrong_future = salt.ext.tornado.gen.Future()
+        wrong_future = tornado.gen.Future()
 
         result = yield self.handler.job_not_running(
             jid=42, tgt="*", tgt_type="glob", minions=[], is_finished=wrong_future
@@ -58,14 +59,14 @@ class TestJobNotRunning(salt.ext.tornado.testing.AsyncTestCase):
 
         self.assertTrue(result)
 
-    @salt.ext.tornado.testing.gen_test
+    @tornado.testing.gen_test
     def test_when_event_times_out_and_minion_is_not_running_minion_data_should_not_be_set(
         self,
     ):
-        fut = salt.ext.tornado.gen.Future()
+        fut = tornado.gen.Future()
         fut.set_exception(saltnado.TimeoutException())
         self.mock.event_listener.get_event.return_value = fut
-        wrong_future = salt.ext.tornado.gen.Future()
+        wrong_future = tornado.gen.Future()
         minions = {}
 
         result = yield self.handler.job_not_running(
@@ -74,20 +75,20 @@ class TestJobNotRunning(salt.ext.tornado.testing.AsyncTestCase):
 
         assert not minions
 
-    @salt.ext.tornado.testing.gen_test
+    @tornado.testing.gen_test
     def test_when_event_finally_finishes_and_returned_minion_not_in_minions_it_should_be_set_to_False(
         self,
     ):
         expected_id = 42
-        no_data_event = salt.ext.tornado.gen.Future()
+        no_data_event = tornado.gen.Future()
         no_data_event.set_result({"data": {}})
-        empty_return_event = salt.ext.tornado.gen.Future()
+        empty_return_event = tornado.gen.Future()
         empty_return_event.set_result({"data": {"return": {}}})
-        actual_return_event = salt.ext.tornado.gen.Future()
+        actual_return_event = tornado.gen.Future()
         actual_return_event.set_result(
             {"data": {"return": {"something happened here": "OK?"}, "id": expected_id}}
         )
-        timed_out_event = salt.ext.tornado.gen.Future()
+        timed_out_event = tornado.gen.Future()
         timed_out_event.set_exception(saltnado.TimeoutException())
         self.mock.event_listener.get_event.side_effect = [
             no_data_event,
@@ -103,27 +104,27 @@ class TestJobNotRunning(salt.ext.tornado.testing.AsyncTestCase):
             tgt="*",
             tgt_type="fnord",
             minions=minions,
-            is_finished=salt.ext.tornado.gen.Future(),
+            is_finished=tornado.gen.Future(),
         )
 
         self.assertFalse(minions[expected_id])
 
-    @salt.ext.tornado.testing.gen_test
+    @tornado.testing.gen_test
     def test_when_event_finally_finishes_and_returned_minion_already_in_minions_it_should_not_be_changed(
         self,
     ):
         expected_id = 42
         expected_value = object()
         minions = {expected_id: expected_value}
-        no_data_event = salt.ext.tornado.gen.Future()
+        no_data_event = tornado.gen.Future()
         no_data_event.set_result({"data": {}})
-        empty_return_event = salt.ext.tornado.gen.Future()
+        empty_return_event = tornado.gen.Future()
         empty_return_event.set_result({"data": {"return": {}}})
-        actual_return_event = salt.ext.tornado.gen.Future()
+        actual_return_event = tornado.gen.Future()
         actual_return_event.set_result(
             {"data": {"return": {"something happened here": "OK?"}, "id": expected_id}}
         )
-        timed_out_event = salt.ext.tornado.gen.Future()
+        timed_out_event = tornado.gen.Future()
         timed_out_event.set_exception(saltnado.TimeoutException())
         self.mock.event_listener.get_event.side_effect = [
             no_data_event,
@@ -138,22 +139,22 @@ class TestJobNotRunning(salt.ext.tornado.testing.AsyncTestCase):
             tgt="*",
             tgt_type="fnord",
             minions=minions,
-            is_finished=salt.ext.tornado.gen.Future(),
+            is_finished=tornado.gen.Future(),
         )
 
         self.assertIs(minions[expected_id], expected_value)
 
-    @salt.ext.tornado.testing.gen_test
+    @tornado.testing.gen_test
     def test_when_event_returns_early_and_finally_times_out_result_should_be_True(self):
-        no_data_event = salt.ext.tornado.gen.Future()
+        no_data_event = tornado.gen.Future()
         no_data_event.set_result({"data": {}})
-        empty_return_event = salt.ext.tornado.gen.Future()
+        empty_return_event = tornado.gen.Future()
         empty_return_event.set_result({"data": {"return": {}}})
-        actual_return_event = salt.ext.tornado.gen.Future()
+        actual_return_event = tornado.gen.Future()
         actual_return_event.set_result(
             {"data": {"return": {"something happened here": "OK?"}, "id": "fnord"}}
         )
-        timed_out_event = salt.ext.tornado.gen.Future()
+        timed_out_event = tornado.gen.Future()
         timed_out_event.set_exception(saltnado.TimeoutException())
         self.mock.event_listener.get_event.side_effect = [
             no_data_event,
@@ -168,21 +169,21 @@ class TestJobNotRunning(salt.ext.tornado.testing.AsyncTestCase):
             tgt="*",
             tgt_type="fnord",
             minions={},
-            is_finished=salt.ext.tornado.gen.Future(),
+            is_finished=tornado.gen.Future(),
         )
         self.assertTrue(result)
 
-    @salt.ext.tornado.testing.gen_test
+    @tornado.testing.gen_test
     def test_when_event_finishes_but_is_finished_is_done_then_result_should_be_True(
         self,
     ):
         expected_minion_id = "fnord"
         expected_minion_value = object()
-        no_data_event = salt.ext.tornado.gen.Future()
+        no_data_event = tornado.gen.Future()
         no_data_event.set_result({"data": {}})
-        empty_return_event = salt.ext.tornado.gen.Future()
+        empty_return_event = tornado.gen.Future()
         empty_return_event.set_result({"data": {"return": {}}})
-        actual_return_event = salt.ext.tornado.gen.Future()
+        actual_return_event = tornado.gen.Future()
         actual_return_event.set_result(
             {
                 "data": {
@@ -191,11 +192,11 @@ class TestJobNotRunning(salt.ext.tornado.testing.AsyncTestCase):
                 }
             }
         )
-        is_finished = salt.ext.tornado.gen.Future()
+        is_finished = tornado.gen.Future()
 
         def abort(*args, **kwargs):
             yield actual_return_event
-            f = salt.ext.tornado.gen.Future()
+            f = tornado.gen.Future()
             f.set_exception(saltnado.TimeoutException())
             is_finished.set_result("This is done")
             yield f
@@ -218,14 +219,14 @@ class TestJobNotRunning(salt.ext.tornado.testing.AsyncTestCase):
         self.assertTrue(len(minions) == 1, str(minions))
         self.assertIs(minions[expected_minion_id], expected_minion_value)
 
-    @salt.ext.tornado.testing.gen_test
+    @tornado.testing.gen_test
     def test_when_is_finished_times_out_before_event_finishes_result_should_be_True(
         self,
     ):
         # Other test times out with event - this one should time out for is_finished
-        finished = salt.ext.tornado.gen.Future()
+        finished = tornado.gen.Future()
         finished.set_exception(saltnado.TimeoutException())
-        wrong_future = salt.ext.tornado.gen.Future()
+        wrong_future = tornado.gen.Future()
         self.mock.event_listener.get_event.return_value = wrong_future
 
         result = yield self.handler.job_not_running(
@@ -234,13 +235,13 @@ class TestJobNotRunning(salt.ext.tornado.testing.AsyncTestCase):
 
         self.assertTrue(result)
 
-    @salt.ext.tornado.testing.gen_test
+    @tornado.testing.gen_test
     def test_when_is_finished_times_out_before_event_finishes_event_should_have_result_set_to_None(
         self,
     ):
-        finished = salt.ext.tornado.gen.Future()
+        finished = tornado.gen.Future()
         finished.set_exception(saltnado.TimeoutException())
-        wrong_future = salt.ext.tornado.gen.Future()
+        wrong_future = tornado.gen.Future()
         self.mock.event_listener.get_event.return_value = wrong_future
 
         result = yield self.handler.job_not_running(
@@ -251,7 +252,7 @@ class TestJobNotRunning(salt.ext.tornado.testing.AsyncTestCase):
 
 
 # TODO: I think we can extract seUp into a superclass -W. Werner, 2020-11-03
-class TestGetMinionReturns(salt.ext.tornado.testing.AsyncTestCase):
+class TestGetMinionReturns(tornado.testing.AsyncTestCase):
     def setUp(self):
         super().setUp()
         self.mock = MagicMock()
@@ -265,22 +266,22 @@ class TestGetMinionReturns(salt.ext.tornado.testing.AsyncTestCase):
             "gather_job_timeout": 10.001,
         }
         self.handler = saltnado.SaltAPIHandler(self.mock, self.mock)
-        f = salt.ext.tornado.gen.Future()
+        f = tornado.gen.Future()
         f.set_result({"jid": f, "minions": []})
 
-    @salt.ext.tornado.testing.gen_test
+    @tornado.testing.gen_test
     def test_if_finished_before_any_events_return_then_result_should_be_empty_dictionary(
         self,
     ):
         expected_result = {}
-        xxx = salt.ext.tornado.gen.Future()
+        xxx = tornado.gen.Future()
         xxx.set_result(None)
-        is_finished = salt.ext.tornado.gen.Future()
+        is_finished = tornado.gen.Future()
         is_finished.set_result(None)
         actual_result = yield self.handler.get_minion_returns(
             events=[],
             is_finished=is_finished,
-            is_timed_out=salt.ext.tornado.gen.Future(),
+            is_timed_out=tornado.gen.Future(),
             min_wait_time=xxx,
             minions={},
         )
@@ -288,7 +289,7 @@ class TestGetMinionReturns(salt.ext.tornado.testing.AsyncTestCase):
 
     # TODO: Copy above - test with timed out -W. Werner, 2020-11-05
 
-    @salt.ext.tornado.testing.gen_test
+    @tornado.testing.gen_test
     def test_if_is_finished_after_events_return_then_result_should_contain_event_result_data(
         self,
     ):
@@ -296,15 +297,15 @@ class TestGetMinionReturns(salt.ext.tornado.testing.AsyncTestCase):
             "minion1": {"fnord": "this is some fnordish data"},
             "minion2": {"fnord": "this is some other fnordish data"},
         }
-        xxx = salt.ext.tornado.gen.Future()
+        xxx = tornado.gen.Future()
         xxx.set_result(None)
-        is_finished = salt.ext.tornado.gen.Future()
+        is_finished = tornado.gen.Future()
         # XXX what do I do here?
         events = [
-            salt.ext.tornado.gen.Future(),
-            salt.ext.tornado.gen.Future(),
-            salt.ext.tornado.gen.Future(),
-            salt.ext.tornado.gen.Future(),
+            tornado.gen.Future(),
+            tornado.gen.Future(),
+            tornado.gen.Future(),
+            tornado.gen.Future(),
         ]
         events[0].set_result(
             {
@@ -323,7 +324,7 @@ class TestGetMinionReturns(salt.ext.tornado.testing.AsyncTestCase):
         actual_result = yield self.handler.get_minion_returns(
             events=events,
             is_finished=is_finished,
-            is_timed_out=salt.ext.tornado.gen.Future(),
+            is_timed_out=tornado.gen.Future(),
             min_wait_time=xxx,
             minions={
                 "minion1": False,
@@ -334,7 +335,7 @@ class TestGetMinionReturns(salt.ext.tornado.testing.AsyncTestCase):
 
         assert actual_result == expected_result
 
-    @salt.ext.tornado.testing.gen_test
+    @tornado.testing.gen_test
     def test_if_timed_out_after_events_return_then_result_should_contain_event_result_data(
         self,
     ):
@@ -342,15 +343,15 @@ class TestGetMinionReturns(salt.ext.tornado.testing.AsyncTestCase):
             "minion1": {"fnord": "this is some fnordish data"},
             "minion2": {"fnord": "this is some other fnordish data"},
         }
-        xxx = salt.ext.tornado.gen.Future()
+        xxx = tornado.gen.Future()
         xxx.set_result(None)
-        is_timed_out = salt.ext.tornado.gen.Future()
+        is_timed_out = tornado.gen.Future()
         # XXX what do I do here?
         events = [
-            salt.ext.tornado.gen.Future(),
-            salt.ext.tornado.gen.Future(),
-            salt.ext.tornado.gen.Future(),
-            salt.ext.tornado.gen.Future(),
+            tornado.gen.Future(),
+            tornado.gen.Future(),
+            tornado.gen.Future(),
+            tornado.gen.Future(),
         ]
         events[0].set_result(
             {
@@ -368,7 +369,7 @@ class TestGetMinionReturns(salt.ext.tornado.testing.AsyncTestCase):
 
         actual_result = yield self.handler.get_minion_returns(
             events=events,
-            is_finished=salt.ext.tornado.gen.Future(),
+            is_finished=tornado.gen.Future(),
             is_timed_out=is_timed_out,
             min_wait_time=xxx,
             minions={
@@ -380,7 +381,7 @@ class TestGetMinionReturns(salt.ext.tornado.testing.AsyncTestCase):
 
         assert actual_result == expected_result
 
-    @salt.ext.tornado.testing.gen_test
+    @tornado.testing.gen_test
     def test_if_wait_timer_is_not_done_even_though_results_are_then_data_should_not_yet_be_returned(
         self,
     ):
@@ -388,18 +389,18 @@ class TestGetMinionReturns(salt.ext.tornado.testing.AsyncTestCase):
             "one": {"fnordy one": "one has some data"},
             "two": {"fnordy two": "two has some data"},
         }
-        events = [salt.ext.tornado.gen.Future(), salt.ext.tornado.gen.Future()]
+        events = [tornado.gen.Future(), tornado.gen.Future()]
         events[0].set_result(
             {"tag": "fnord", "data": {"id": "one", "return": expected_result["one"]}}
         )
         events[1].set_result(
             {"tag": "fnord", "data": {"id": "two", "return": expected_result["two"]}}
         )
-        wait_timer = salt.ext.tornado.gen.Future()
+        wait_timer = tornado.gen.Future()
         fut = self.handler.get_minion_returns(
             events=events,
-            is_finished=salt.ext.tornado.gen.Future(),
-            is_timed_out=salt.ext.tornado.gen.Future(),
+            is_finished=tornado.gen.Future(),
+            is_timed_out=tornado.gen.Future(),
             min_wait_time=wait_timer,
             minions={"one": False, "two": False},
         )
@@ -408,7 +409,7 @@ class TestGetMinionReturns(salt.ext.tornado.testing.AsyncTestCase):
             yield fut
 
         self.io_loop.spawn_callback(boop)
-        yield salt.ext.tornado.gen.sleep(0.1)
+        yield tornado.gen.sleep(0.1)
 
         assert not fut.done()
 
@@ -417,30 +418,30 @@ class TestGetMinionReturns(salt.ext.tornado.testing.AsyncTestCase):
 
         assert actual_result == expected_result
 
-    @salt.ext.tornado.testing.gen_test
+    @tornado.testing.gen_test
     def test_when_is_finished_any_other_futures_should_be_canceled(self):
         events = [
-            salt.ext.tornado.gen.Future(),
-            salt.ext.tornado.gen.Future(),
-            salt.ext.tornado.gen.Future(),
-            salt.ext.tornado.gen.Future(),
-            salt.ext.tornado.gen.Future(),
+            tornado.gen.Future(),
+            tornado.gen.Future(),
+            tornado.gen.Future(),
+            tornado.gen.Future(),
+            tornado.gen.Future(),
         ]
 
-        is_finished = salt.ext.tornado.gen.Future()
+        is_finished = tornado.gen.Future()
         is_finished.set_result(None)
         yield self.handler.get_minion_returns(
             events=events,
             is_finished=is_finished,
-            is_timed_out=salt.ext.tornado.gen.Future(),
-            min_wait_time=salt.ext.tornado.gen.Future(),
+            is_timed_out=tornado.gen.Future(),
+            min_wait_time=tornado.gen.Future(),
             minions={"one": False, "two": False},
         )
 
         are_done = [event.done() for event in events]
         assert all(are_done)
 
-    @salt.ext.tornado.testing.gen_test
+    @tornado.testing.gen_test
     def test_when_an_event_times_out_then_we_should_not_enter_an_infinite_loop(self):
         # NOTE: this test will enter an infinite loop if the code is broken. I
         # was not able to figure out a way to ensure that the test exits with
@@ -451,27 +452,27 @@ class TestGetMinionReturns(salt.ext.tornado.testing.AsyncTestCase):
         # TimeoutException.
 
         events = [
-            salt.ext.tornado.gen.Future(),
-            salt.ext.tornado.gen.Future(),
-            salt.ext.tornado.gen.Future(),
-            salt.ext.tornado.gen.Future(),
-            salt.ext.tornado.gen.Future(),
+            tornado.gen.Future(),
+            tornado.gen.Future(),
+            tornado.gen.Future(),
+            tornado.gen.Future(),
+            tornado.gen.Future(),
         ]
 
         # Arguably any event would work, but 3 isn't the first, so it
         # gives us a little more confidence that this test is testing
         # correctly
         events[3].set_exception(saltnado.TimeoutException())
-        times_out_later = salt.ext.tornado.gen.Future()
+        times_out_later = tornado.gen.Future()
         # 0.5s should be long enough that the test gets through doing other
         # things before hitting this timeout, which will cancel all the
         # in-flight futures.
         self.io_loop.call_later(0.5, lambda: times_out_later.set_result(None))
         yield self.handler.get_minion_returns(
             events=events,
-            is_finished=salt.ext.tornado.gen.Future(),
+            is_finished=tornado.gen.Future(),
             is_timed_out=times_out_later,
-            min_wait_time=salt.ext.tornado.gen.Future(),
+            min_wait_time=tornado.gen.Future(),
             minions={"one": False, "two": False},
         )
 
@@ -482,7 +483,7 @@ class TestGetMinionReturns(salt.ext.tornado.testing.AsyncTestCase):
         assert all(are_done)
         assert times_out_later.done()
 
-    @salt.ext.tornado.testing.gen_test
+    @tornado.testing.gen_test
     def test_when_is_timed_out_any_other_futures_should_be_canceled(self):
         # There is some question about whether this test is or should be
         # necessary. Or if it's meaningful. The code that this is testing
@@ -491,46 +492,46 @@ class TestGetMinionReturns(salt.ext.tornado.testing.AsyncTestCase):
         # That being said, the worst case is that this is just a duplicate
         # or irrelevant test, and can be removed.
         events = [
-            salt.ext.tornado.gen.Future(),
-            salt.ext.tornado.gen.Future(),
-            salt.ext.tornado.gen.Future(),
-            salt.ext.tornado.gen.Future(),
-            salt.ext.tornado.gen.Future(),
+            tornado.gen.Future(),
+            tornado.gen.Future(),
+            tornado.gen.Future(),
+            tornado.gen.Future(),
+            tornado.gen.Future(),
         ]
 
-        is_timed_out = salt.ext.tornado.gen.Future()
+        is_timed_out = tornado.gen.Future()
         is_timed_out.set_result(None)
         yield self.handler.get_minion_returns(
             events=events,
-            is_finished=salt.ext.tornado.gen.Future(),
+            is_finished=tornado.gen.Future(),
             is_timed_out=is_timed_out,
-            min_wait_time=salt.ext.tornado.gen.Future(),
+            min_wait_time=tornado.gen.Future(),
             minions={"one": False, "two": False},
         )
 
         are_done = [event.done() for event in events]
         assert all(are_done)
 
-    @salt.ext.tornado.testing.gen_test
+    @tornado.testing.gen_test
     def test_when_min_wait_time_and_nothing_todo_any_other_futures_should_be_canceled(
         self,
     ):
         events = [
-            salt.ext.tornado.gen.Future(),
-            salt.ext.tornado.gen.Future(),
-            salt.ext.tornado.gen.Future(),
-            salt.ext.tornado.gen.Future(),
-            salt.ext.tornado.gen.Future(),
+            tornado.gen.Future(),
+            tornado.gen.Future(),
+            tornado.gen.Future(),
+            tornado.gen.Future(),
+            tornado.gen.Future(),
         ]
 
-        is_finished = salt.ext.tornado.gen.Future()
-        min_wait_time = salt.ext.tornado.gen.Future()
+        is_finished = tornado.gen.Future()
+        min_wait_time = tornado.gen.Future()
         self.io_loop.call_later(0.2, lambda: min_wait_time.set_result(None))
 
         yield self.handler.get_minion_returns(
             events=events,
             is_finished=is_finished,
-            is_timed_out=salt.ext.tornado.gen.Future(),
+            is_timed_out=tornado.gen.Future(),
             min_wait_time=min_wait_time,
             minions={"one": True, "two": True},
         )
@@ -538,37 +539,37 @@ class TestGetMinionReturns(salt.ext.tornado.testing.AsyncTestCase):
         are_done = [event.done() for event in events] + [is_finished.done()]
         assert all(are_done)
 
-    @salt.ext.tornado.testing.gen_test
+    @tornado.testing.gen_test
     def test_when_is_finished_but_not_is_timed_out_then_timed_out_should_not_be_set_to_done(
         self,
     ):
-        events = [salt.ext.tornado.gen.Future()]
-        is_timed_out = salt.ext.tornado.gen.Future()
-        is_finished = salt.ext.tornado.gen.Future()
+        events = [tornado.gen.Future()]
+        is_timed_out = tornado.gen.Future()
+        is_finished = tornado.gen.Future()
         is_finished.set_result(None)
 
         yield self.handler.get_minion_returns(
             events=events,
             is_finished=is_finished,
             is_timed_out=is_timed_out,
-            min_wait_time=salt.ext.tornado.gen.Future(),
+            min_wait_time=tornado.gen.Future(),
             minions={"one": False, "two": False},
         )
 
         assert not is_timed_out.done()
 
-    @salt.ext.tornado.testing.gen_test
+    @tornado.testing.gen_test
     def test_when_min_wait_time_and_all_completed_but_not_is_timed_out_then_timed_out_should_not_be_set_to_done(
         self,
     ):
-        events = [salt.ext.tornado.gen.Future()]
-        is_timed_out = salt.ext.tornado.gen.Future()
-        min_wait_time = salt.ext.tornado.gen.Future()
+        events = [tornado.gen.Future()]
+        is_timed_out = tornado.gen.Future()
+        min_wait_time = tornado.gen.Future()
         self.io_loop.call_later(0.2, lambda: min_wait_time.set_result(None))
 
         yield self.handler.get_minion_returns(
             events=events,
-            is_finished=salt.ext.tornado.gen.Future(),
+            is_finished=tornado.gen.Future(),
             is_timed_out=is_timed_out,
             min_wait_time=min_wait_time,
             minions={"one": True},
@@ -576,21 +577,21 @@ class TestGetMinionReturns(salt.ext.tornado.testing.AsyncTestCase):
 
         assert not is_timed_out.done()
 
-    @salt.ext.tornado.testing.gen_test
+    @tornado.testing.gen_test
     def test_when_things_are_completed_but_not_timed_out_then_timed_out_event_should_not_be_done(
         self,
     ):
         events = [
-            salt.ext.tornado.gen.Future(),
+            tornado.gen.Future(),
         ]
         events[0].set_result({"tag": "fnord", "data": {"id": "one", "return": {}}})
-        min_wait_time = salt.ext.tornado.gen.Future()
+        min_wait_time = tornado.gen.Future()
         min_wait_time.set_result(None)
-        is_timed_out = salt.ext.tornado.gen.Future()
+        is_timed_out = tornado.gen.Future()
 
         yield self.handler.get_minion_returns(
             events=events,
-            is_finished=salt.ext.tornado.gen.Future(),
+            is_finished=tornado.gen.Future(),
             is_timed_out=is_timed_out,
             min_wait_time=min_wait_time,
             minions={"one": True},
@@ -599,7 +600,7 @@ class TestGetMinionReturns(salt.ext.tornado.testing.AsyncTestCase):
         assert not is_timed_out.done()
 
 
-class TestDisbatchLocal(salt.ext.tornado.testing.AsyncTestCase):
+class TestDisbatchLocal(tornado.testing.AsyncTestCase):
     def setUp(self):
         super().setUp()
         self.mock = MagicMock()
@@ -614,12 +615,12 @@ class TestDisbatchLocal(salt.ext.tornado.testing.AsyncTestCase):
         }
         self.handler = saltnado.SaltAPIHandler(self.mock, self.mock)
 
-    @salt.ext.tornado.testing.gen_test
+    @tornado.testing.gen_test
     def test_when_is_timed_out_is_set_before_other_events_are_completed_then_result_should_be_empty_dictionary(
         self,
     ):
-        completed_event = salt.ext.tornado.gen.Future()
-        never_completed = salt.ext.tornado.gen.Future()
+        completed_event = tornado.gen.Future()
+        never_completed = tornado.gen.Future()
         # TODO: We may need to tweak these values to get them close enough but not so far away -W. Werner, 2020-11-17
         gather_timeout = 0.1
         event_timeout = gather_timeout + 0.05
@@ -642,7 +643,7 @@ class TestDisbatchLocal(salt.ext.tornado.testing.AsyncTestCase):
 
         self.io_loop.call_later(event_timeout, completer)
 
-        f = salt.ext.tornado.gen.Future()
+        f = tornado.gen.Future()
         f.set_result({"jid": "42", "minions": []})
         with patch.object(
             self.handler.application.event_listener,
@@ -660,12 +661,12 @@ class TestDisbatchLocal(salt.ext.tornado.testing.AsyncTestCase):
 
         assert result == {}
 
-    @salt.ext.tornado.testing.gen_test
+    @tornado.testing.gen_test
     def test_when_is_finished_is_set_before_events_return_then_no_data_should_be_returned(
         self,
     ):
-        completed_event = salt.ext.tornado.gen.Future()
-        never_completed = salt.ext.tornado.gen.Future()
+        completed_event = tornado.gen.Future()
+        never_completed = tornado.gen.Future()
         gather_timeout = 2
         event_timeout = gather_timeout - 1
 
@@ -692,7 +693,7 @@ class TestDisbatchLocal(salt.ext.tornado.testing.AsyncTestCase):
             assert finished is not None
             finished.set_result(42)
 
-        f = salt.ext.tornado.gen.Future()
+        f = tornado.gen.Future()
         f.set_result({"jid": "42", "minions": []})
         with patch.object(
             self.handler.application.event_listener,
@@ -715,13 +716,13 @@ class TestDisbatchLocal(salt.ext.tornado.testing.AsyncTestCase):
 
         assert result == {}
 
-    @salt.ext.tornado.testing.gen_test
+    @tornado.testing.gen_test
     def test_when_is_finished_then_all_collected_data_should_be_returned(self):
-        completed_event = salt.ext.tornado.gen.Future()
-        never_completed = salt.ext.tornado.gen.Future()
+        completed_event = tornado.gen.Future()
+        never_completed = tornado.gen.Future()
         # This timeout should never be reached
         gather_timeout = 42
-        completed_events = [salt.ext.tornado.gen.Future() for _ in range(5)]
+        completed_events = [tornado.gen.Future() for _ in range(5)]
         for i, event in enumerate(completed_events):
             event.set_result(
                 {
@@ -732,7 +733,7 @@ class TestDisbatchLocal(salt.ext.tornado.testing.AsyncTestCase):
                     },
                 }
             )
-        uncompleted_events = [salt.ext.tornado.gen.Future() for _ in range(5)]
+        uncompleted_events = [tornado.gen.Future() for _ in range(5)]
         events = iter(completed_events + uncompleted_events)
         expected_result = {
             "fnord 0": "return from fnord 0",
@@ -753,7 +754,7 @@ class TestDisbatchLocal(salt.ext.tornado.testing.AsyncTestCase):
             assert finished is not None
             finished.set_result(42)
 
-        f = salt.ext.tornado.gen.Future()
+        f = tornado.gen.Future()
         f.set_result({"jid": "42", "minions": ["non-existent minion"]})
         with patch.object(
             self.handler.application.event_listener,
@@ -776,16 +777,16 @@ class TestDisbatchLocal(salt.ext.tornado.testing.AsyncTestCase):
 
         assert result == expected_result
 
-    @salt.ext.tornado.testing.gen_test
+    @tornado.testing.gen_test
     def test_when_is_timed_out_then_all_collected_data_should_be_returned(self):
-        completed_event = salt.ext.tornado.gen.Future()
-        never_completed = salt.ext.tornado.gen.Future()
+        completed_event = tornado.gen.Future()
+        never_completed = tornado.gen.Future()
         # 2s is probably enough for any kind of computer to manage to
         # do all the other processing. We could maybe reduce this - just
         # depends on how slow of a system we're running on.
         # TODO: Maybe we should have a test helper/fixture that benchmarks the system and gets a reasonable timeout? -W. Werner, 2020-11-19
         gather_timeout = 2
-        completed_events = [salt.ext.tornado.gen.Future() for _ in range(5)]
+        completed_events = [tornado.gen.Future() for _ in range(5)]
         for i, event in enumerate(completed_events):
             event.set_result(
                 {
@@ -796,7 +797,7 @@ class TestDisbatchLocal(salt.ext.tornado.testing.AsyncTestCase):
                     },
                 }
             )
-        uncompleted_events = [salt.ext.tornado.gen.Future() for _ in range(5)]
+        uncompleted_events = [tornado.gen.Future() for _ in range(5)]
         events = iter(completed_events + uncompleted_events)
         expected_result = {
             "fnord 0": "return from fnord 0",
@@ -812,7 +813,7 @@ class TestDisbatchLocal(salt.ext.tornado.testing.AsyncTestCase):
             else:
                 return next(events)
 
-        f = salt.ext.tornado.gen.Future()
+        f = tornado.gen.Future()
         f.set_result({"jid": "42", "minions": ["non-existent minion"]})
         with patch.object(
             self.handler.application.event_listener,
@@ -830,13 +831,13 @@ class TestDisbatchLocal(salt.ext.tornado.testing.AsyncTestCase):
 
         assert result == expected_result
 
-    @salt.ext.tornado.testing.gen_test
+    @tornado.testing.gen_test
     def test_when_minions_all_return_then_all_collected_data_should_be_returned(self):
-        completed_event = salt.ext.tornado.gen.Future()
-        never_completed = salt.ext.tornado.gen.Future()
+        completed_event = tornado.gen.Future()
+        never_completed = tornado.gen.Future()
         # Timeout is something ridiculously high - it should never be reached
         gather_timeout = 20
-        completed_events = [salt.ext.tornado.gen.Future() for _ in range(10)]
+        completed_events = [tornado.gen.Future() for _ in range(10)]
         events_by_id = {}
         for i, event in enumerate(completed_events):
             id_ = f"fnord {i}"
@@ -864,7 +865,7 @@ class TestDisbatchLocal(salt.ext.tornado.testing.AsyncTestCase):
             tag = kwargs.get("tag", "").rpartition("/")[-1]
             return events_by_id.get(tag, never_completed)
 
-        f = salt.ext.tornado.gen.Future()
+        f = tornado.gen.Future()
         f.set_result(
             {
                 "jid": "42",
@@ -887,15 +888,15 @@ class TestDisbatchLocal(salt.ext.tornado.testing.AsyncTestCase):
 
         assert result == expected_result
 
-    @salt.ext.tornado.testing.gen_test
+    @tornado.testing.gen_test
     def test_when_min_wait_time_has_not_passed_then_disbatch_should_not_return_expected_data_until_time_has_passed(
         self,
     ):
-        completed_event = salt.ext.tornado.gen.Future()
-        never_completed = salt.ext.tornado.gen.Future()
-        wait_timer = salt.ext.tornado.gen.Future()
+        completed_event = tornado.gen.Future()
+        never_completed = tornado.gen.Future()
+        wait_timer = tornado.gen.Future()
         gather_timeout = 20
-        completed_events = [salt.ext.tornado.gen.Future() for _ in range(10)]
+        completed_events = [tornado.gen.Future() for _ in range(10)]
         events_by_id = {}
         # Setup some real-enough looking return data
         for i, event in enumerate(completed_events):
@@ -943,11 +944,11 @@ class TestDisbatchLocal(salt.ext.tornado.testing.AsyncTestCase):
         # The fake sleep is necessary so that we can return our own
         # min_wait_time future. The fakeo_timer object is how we signal
         # which one we need to be returning.
-        orig_sleep = salt.ext.tornado.gen.sleep
+        orig_sleep = tornado.gen.sleep
 
         fakeo_timer = object()
 
-        @salt.ext.tornado.gen.coroutine
+        @tornado.gen.coroutine
         def fake_sleep(timer):
             # only return our fake min_wait_time future when the sentinel
             # value is provided. Otherwise it's just a number.
@@ -956,7 +957,7 @@ class TestDisbatchLocal(salt.ext.tornado.testing.AsyncTestCase):
             else:
                 yield orig_sleep(timer)
 
-        f = salt.ext.tornado.gen.Future()
+        f = tornado.gen.Future()
         f.set_result(
             {
                 "jid": "42",
@@ -981,7 +982,7 @@ class TestDisbatchLocal(salt.ext.tornado.testing.AsyncTestCase):
                 "order_masters": True,
             },
         ), patch(
-            "salt.ext.tornado.gen.sleep",
+            "tornado.gen.sleep",
             autospec=True,
             side_effect=fake_sleep,
         ), patch.dict(
@@ -1009,7 +1010,7 @@ class TestDisbatchLocal(salt.ext.tornado.testing.AsyncTestCase):
                 yield fut
 
             self.io_loop.spawn_callback(boop)
-            yield salt.ext.tornado.gen.sleep(0.1)
+            yield tornado.gen.sleep(0.1)
             # here, all the minions should be complete (i.e. "True")
             assert all(minions[m_id] for m_id in minions)
             # But _disbatch_local is not returned yet because min_wait_time has not passed
